@@ -1,26 +1,27 @@
 import itertools
-import logging
-from typing import List, Tuple, Union
-from .event import EventType
+from typing import List, Tuple, Union, Callable
 from .message import Message, PrivateMessage
 from .chat import DGGChat
 
 
 class DGGBot(DGGChat):
 
-    def __init__(self, auth_token=None, username=None, prefix='!'):
+    def __init__(self, auth_token: str = None, username: str = None, owner: str = None, prefix='!'):
         super().__init__(auth_token=auth_token, username=username)
+        self._owner = owner.lower()
         self.prefix = prefix
         self._commands = {}
         self._mention = {}
         self._events = {}
 
-    def command(self, name: str = None,
-                aliases: Union[List[str], Tuple[str]] = tuple(),
-                **kwargs):
-        """Decorator to add commands to bot."""
-        def decorator(func):
-            for cmd_name in itertools.chain((name or func.__name__,), aliases):
+    def command(self, aliases: Union[List[str], Tuple[str]] = tuple(), *args, **kwargs):
+        """
+        Decorator to add commands to bot.
+        :param aliases: aliases to call the function besides the function name
+        :return:
+        """
+        def decorator(func: Callable):
+            for cmd_name in itertools.chain((func.__name__,), aliases):
                 if cmd_name in self._commands:
                     raise Exception(f'Command name "{cmd_name}" already exists.')
                 else:
@@ -29,6 +30,16 @@ class DGGBot(DGGChat):
 
         return decorator
 
+    def is_owner(self):
+        """Decorator to add 'owner' permission required to a command."""
+        def decorator(func: Callable):
+            if not hasattr(func, "_perms"):
+                func._perms = []
+            perm = "owner"
+            func._perms.append(perm)
+            return func
+        return decorator
+
     def mention(self):
         """Decorator to add auto-replies to bot."""
         def decorator(func):
@@ -36,12 +47,16 @@ class DGGBot(DGGChat):
             return func
         return decorator
 
-    def on_mention(self, msg):
+    def on_mention(self, msg: Message):
         for func in self._mention.values():
             if func(msg):
                 break
 
-    def on_msg(self, msg):
+    def on_msg(self, msg: Message):
+        if self.is_command(msg):
+            self.on_command(msg)
+
+    def on_privmsg(self, msg: PrivateMessage):
         if self.is_command(msg):
             self.on_command(msg)
 
@@ -51,4 +66,8 @@ class DGGBot(DGGChat):
     def on_command(self, msg: Message):
         cmd = msg.data.split(' ')[0][1:]
         if cmd in self._commands:
+            if hasattr(self._commands[cmd], "_perms"):
+                perms = self._commands[cmd]._perms
+                if "owner" in perms and msg.nick.lower() != self._owner:
+                    return
             self._commands[cmd](msg)
